Module: At
- Included in:
- Object
- Defined in:
- lib/at.rb,
lib/at/instance_variable_delegator.rb
Overview
At is a small library provides an at method for all Objects which allows you to access instance variables on an object as if they were accessors for testing purposes, usually within test setups and teardowns
Defined Under Namespace
Classes: InstanceVariableDelegator
Instance Method Summary collapse
-
#_at ⇒ InstanceVariableDelegator
(also: #at)
The memoized InstanceVariableDelegator proxy instance for this Object instance.
Instance Method Details
#_at ⇒ InstanceVariableDelegator Also known as: at
Returns The memoized InstanceVariableDelegator proxy instance for this Object instance.
10 11 12 |
# File 'lib/at.rb', line 10 def _at @_at ||= InstanceVariableDelegator.new(self) end |